@@ -1,6 +1,5 @@
-__version__ = '1.1dev'
+__version__ = '1.2'
 __author__ = "Simon Fell et al. reluctantly forked by idbentley"
-__credits__ = "Mad shouts to the sforce possie"
 __copyright__ = "GNU GPL 2."
 
 import httplib
@@ -133,6 +132,10 @@ class BeatBoxXmlGenerator(XMLGenerator):
     def __init__(self, destination, encoding):
         XMLGenerator.__init__(self, destination, encoding)
 
+        if self._out:
+            self._write = self._out.write
+            self._flush = self._out.flush
+
     def makeName(self, name):
         if name[0] is None:
             #if the name was not namespace-scoped, use the qualified part
@@ -141,15 +144,15 @@ class BeatBoxXmlGenerator(XMLGenerator):
         return self._current_context[name[0]] + ":" + name[1]
 
     def startElementNS(self, name, qname, attrs):
-        self._out.write('<' + self.makeName(name))
+        self._write(unicode('<' + self.makeName(name)))
 
         for pair in self._undeclared_ns_maps:
-            self._out.write(' xmlns:%s="%s"' % pair)
+            self._write(unicode(' xmlns:%s="%s"' % pair))
         self._undeclared_ns_maps = []
 
         for (name, value) in attrs.items():
-            self._out.write(' %s=%s' % (self.makeName(name), quoteattr(value)))
-        self._out.write('>')
+            self._write(unicode(' %s=%s' % (self.makeName(name), quoteattr(value))))
+        self._write(unicode('>'))
 
 # General purpose xml writer.
 # Does a bunch of useful stuff above & beyond XmlGenerator
@@ -179,7 +182,7 @@ class XmlWriter:
 
     # General Function for writing an XML Element.
     # Detects the type of the element, and handles each type appropriately.
-    # i.e. If a list, then it encodes each element, if a dict, it writes an 
+    # i.e. If a list, then it encodes each element, if a dict, it writes an
     # embedded element.
     def writeElement(self, namespace, name, value, attrs = _noAttrs):
         if islst(value):
@@ -255,7 +258,7 @@ class SoapWriter(XmlWriter):
         self.endPrefixMapping("o")
         self.endPrefixMapping("p")
         self.endPrefixMapping("s")
-        return XmlWriter.endDocument(self)  
+        return XmlWriter.endDocument(self)
 
 # processing for a single soap request / response
 class SoapEnvelope:
